doapfiend.cli

Package doapfiend :: Module cli |
[hide private]
[frames] | no frames]

# Module cli

source code

# cli.py

Command-line tool for querying, serializing and displaying DOAP

Author: Rob Cakebread <rob@doapspace.org>

License : BSD-2

Classes | [hide private]
| DoapFiend `DoapFiend` class

Functions | [hide private]
opt_parser.OptionParser |
setup_opt_parser() Setup the optparser | source code
main() Let's do it. | source code

Variables | [hide private]
| __revision__ = ``'````'``

Function Details | [hide private]

### setup_opt_parser() | source code
Setup the optparser Returns: opt_parser.OptionParser Option parser